@@ -62,6 +62,12 @@ class Rating(GloballyUnique, Base):
                   hint=N_('ID of the user that is responsible for this record.')))
     """ID of the :py:class:`user <.Player>` that is responsible for this record."""
 
+    idclub = Column(
+        intid_t, ForeignKey('clubs.idclub'),
+        info=dict(label=N_('Club ID'),
+                  hint=N_('ID of the club the rating is restricted to.')))
+    """Restricted to :py:class:`club <.Club>`'s ID."""
+
     description = Column(
         description_t,
         nullable=False,
@@ -523,6 +529,8 @@ class Rating(GloballyUnique, Base):
         simple['modified'] = self.modified
         if self.idowner:
             simple['owner'] = serializer.addPlayer(self.owner)
+        if self.idclub:
+            simple['club'] = serializer.addClub(self.club)
         simple['description'] = self.description
         simple['level'] = self.level
         simple['inherit'] = self.inherit
