@@ -280,6 +280,31 @@ Ext.define('SoL.module.Tourneys.Actions', {
                                     value: idclub
                                 }, false);
                             }
+                        },
+                        select: function(combo, records) {
+                            // Alter data directly, to avoid triggering data-changed
+                            record.data['IDClub'] = records[0].get('idclub');
+                        }
+                    }
+                }
+            },
+            Rating: {
+                editor: {
+                    // Force re-execution of the query, the championship (and
+                    // thus the club id) may have changed
+                    queryCaching: false,
+                    listeners: {
+                        beforequery: function(queryPlan) {
+                            var store = queryPlan.combo.store;
+                            var idclub = record.get('IDClub');
+
+                            if(idclub) {
+                                store.addFilter({
+                                    id: 'currentclub',
+                                    property: 'idclub',
+                                    value: "NULL," + idclub
+                                }, false);
+                            }
                         }
                     }
                 }
