@@ -165,7 +165,8 @@ Ext.define('SoL.view.Boards', {
                             root: metadata.root_slot
                         }
                     },
-                    autoDestroy: true
+                    autoDestroy: true,
+                    pageSize: 999
                 });
                 dataview.store.implicitModel = true;
 
