@@ -348,6 +348,7 @@ def championships(request, results):
 @view_config(route_name="tourneys", renderer="json")
 @expose(select([_tourneys_t,
                 _championships_t.c.description.label('Championship'),
+                _championships_t.c.idclub.label('IDClub'),
                 select([_clubs_t.c.description],
                        _clubs_t.c.idclub==_championships_t.c.idclub
                    ).as_scalar().label('Club'),
@@ -380,13 +381,16 @@ def championships(request, results):
     Championship=dict(label=_championships_t.c.description.info['label'],
                       hint=_('Championship this tourney belongs to.'),
                       flex=3,
-                      lookup=dict(url=('/data/championships?only_cols=idchampionship,description,Club'
+                      lookup=dict(url=('/data/championships?only_cols=idchampionship,description,Club,idclub'
                                        '&sort=Club,description'
                                        '&filter_closed=false'),
                                   idField='idchampionship',
                                   displayField='description',
-                                  otherFields='Club',
+                                  otherFields='Club,idclub',
                                   innerTpl='<div>{description}&nbsp;<small>({Club})</small></div>')),
+    IDClub=dict(label=_championships_t.c.idclub.info['label'],
+                hint=_('ID of the club this tourney is organized by.'),
+                hidden=True),
     Club=dict(label=_clubs_t.c.description.info['label'],
               hint=_('Club this tourney is organized by.'),
               flex=3,
@@ -484,6 +488,9 @@ _rates_t = Rate.__table__
 
 @view_config(route_name="ratings", renderer="json")
 @expose(select([_ratings_t,
+                select([_clubs_t.c.description],
+                       _clubs_t.c.idclub==_ratings_t.c.idclub
+                   ).as_scalar().label('Club'),
                 select([func.count(_tourneys_t.c.idtourney)],
                        _tourneys_t.c.idrating==_ratings_t.c.idrating
                    ).as_scalar().label('Tourneys'),
@@ -501,6 +508,22 @@ _rates_t = Rate.__table__
     lower_rate=dict(hidden=True),
     higher_rate=dict(hidden=True),
     outcomes=dict(hidden=True, width=200),
+    Club=dict(label=_clubs_t.c.description.info['label'],
+              hint=_('Club this rating is restricted to.'),
+              flex=1,
+              hidden=True,
+              nullable=True,
+              lookup=dict(url=('/data/clubs?only_cols=idclub,description,nationality'
+                               '&sort=nationality,description'),
+                          idField='idclub',
+                          displayField='description',
+                          otherFields='nationality',
+                          pageSize=12,
+                          innerTpl=('<div class="sol-flags-icon sol-flag-{nationality}"'
+                                    ' data-qtip="'
+                                    '{[ SoL.form.field.FlagsCombo.countries[values.nationality] ]}'
+                                    '">{description}'
+                                    '</div>'))),
     Tourneys=dict(label=_('Tourneys'),
                  hint=_('Number of tourneys using this rating.'),
                  width=80,
